.. image:: https://api.travis-ci.org/krukas/Xenops.svg?branch=master
    :target: https://travis-ci.org/krukas/Xenops

.. image:: https://readthedocs.org/projects/xenops/badge/?version=latest
    :target: http://xenops.readthedocs.io/en/latest

.. image:: https://codecov.io/gh/krukas/Xenops/branch/master/graph/badge.svg
  :target: https://codecov.io/gh/krukas/Xenops

.. image:: https://badge.fury.io/py/Xenops.svg
    :target: https://badge.fury.io/py/Xenops

**PRE PRE ALPHA, still in active development**


Xenops
======

Xenops is a simple program to sync data like (customers/products) between different systems.


Installation
============
To install Xenops, run:

    pip install Xenops

Create new project
==================
For creating a new project, read the documentation.


